# -*- coding: utf-8 -*-
#
# This file is part of fedrepo_req.
# Copyright © 2017 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
"""
Initializes the module and provides helper functions
"""
from __future__ import absolute_import
from datetime import datetime
from copy import deepcopy

import fedrepo_req.config

NAMESPACE_CHOICES = ['rpms', 'container', 'modules', 'test-modules']
MONITOR_CHOICES = ['no-monitoring', 'monitoring', 'monitoring-with-scratch']
STANDARD_BRANCH_SLAS = {
    'epel7': {
        'stable_api': '2024-06-30',
        'security_fixes': '2024-06-30',
        'bug_fixes': '2024-06-30'
    },
    'el6': {
        'stable_api': '2020-11-30',
        'security_fixes': '2020-11-30',
        'bug_fixes': '2020-11-30'
    },
    'f27': {
        'bug_fixes': '2018-11-24',
        'security_fixes': '2018-11-24'
    },
    'f26': {
        'security_fixes': '2018-07-01',
        'bug_fixes': '2018-07-01'
    },
    'f25': {
        'security_fixes': '2018-07-01',
        'bug_fixes': '2017-12-01'
    },
    'f24': {
        'security_fixes': '2017-08-11',
        'bug_fixes': '2017-08-11'
    }
}
today = datetime.utcnow().date()
# Remove any branches that have gone EOL since these were hardcoded. This data
# should really be in PDC, but there is not suitable API yet.
for branch, slas in deepcopy(STANDARD_BRANCH_SLAS).items():
    if not any([datetime.strptime(sla_eol, '%Y-%m-%d').date() >= today
                for sla_eol in slas.values()]):
        STANDARD_BRANCH_SLAS.pop(branch)

CONFIG = fedrepo_req.config.get_config()

from fedrepo_req.fas import FASClient  # noqa: E402
FAS_CLIENT = FASClient()

from fedrepo_req.bugzilla import BugzillaClient  # noqa: E402
BUGZILLA_CLIENT = BugzillaClient()
