# -*- coding: utf-8 -*-
#
# This file is part of fedrepo_req.
# Copyright © 2017 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
"""
Configuration related helper functions
"""
from __future__ import absolute_import
import os
import click
from six.moves import configparser


def get_config():
    """
    An abstraction of using ConfigParser for the project
    :return: ConfigParser object
    """
    config = configparser.ConfigParser()
    home_dir = os.path.expanduser('~')
    paths = [
        '/etc/fedrepo_req/config.ini',
        os.path.join(home_dir, '.config', 'fedrepo_req', 'config.ini'),
    ]
    if os.environ.get('FEDREPO_REQ_TEST_CONFIG', 'false').lower() == 'true':
        test_config_path = os.path.abspath(os.path.join(
            os.path.dirname(__file__), '../tests/test_config.ini'))
        paths.append(test_config_path)

    if not any(os.path.exists(path) for path in paths):
        raise click.ClickException('No configuration file was found')

    config.read(paths)
    return config


def get_config_item(config, section, item):
    """
    Gets a config item and throws a ClickException if it doesn't exist
    :param config: ConfigParser object from get_config
    :param section: string representing the section in the ini (e.g. app)
    :param item: string representing the item in the section you want
    (e.g. pagure_url)
    :return: string of the config item
    """
    try:
        return config.get(section, item)
    except (configparser.NoOptionError, configparser.NoSectionError):
        error_msg = ('The "{0}" setting is not set in the "{1}" section'
                     .format(item, section))
        raise click.ClickException(error_msg)
