# -*- coding: utf-8 -*-
#
# This file is part of fedrepo_req.
# Copyright © 2017 Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
"""
Provides helper functions for FAS
"""
from __future__ import absolute_import
from fedora.client import AccountSystem, AuthError
from fedrepo_req.exceptions import ValidationError


class FASClient(object):
    """
    A helper class to maintain a FAS session
    """
    def __init__(self):
        self.client = AccountSystem('https://admin.fedoraproject.org/accounts')

    def set_credentials(self, username, password):
        """
        A login function to FAS
        :param username: a string of the username
        :param password: a string of the password
        :return: None
        """
        self.client.username = username
        self.client.password = password

    def get_fas_user_by_email(self, email):
        """
        Taken from:
        https://pagure.io/pkgdb-cli/blob/master/f/pkgdb2client/utils.py

        Get the FAS user associated with the provided email
        The email_address can be either the FAS email address or the one used
        in Bugzilla.
        :param email: a string of the email address of the user to
        retrieve in FAS
        :return: a FAS user or None
        """
        if email in self.client._AccountSystem__alternate_email:
            user_id = self.client._AccountSystem__alternate_email[email]
        else:
            try:
                user_id = self.client.people_query(
                    constraints={'email': email},
                    columns=['id']
                )
            except AuthError:
                raise ValidationError('The FAS Client is not authenticated')
            if user_id:
                user_id = user_id[0].id

        if user_id:
            try:
                return self.client.person_by_id(user_id)
            except AuthError:
                raise ValidationError('The FAS Client is not authenticated')
        return None

    @staticmethod
    def user_member_of(user, group):
        """
        Checks
        :param user: a FAS user object
        :param group: a string of the FAS group
        :return: boolean
        """
        return user and group in user['group_roles'] \
            and user['group_roles'][group]['role_status'] == 'approved'
